package com.mdd.admin.validate.system;

import com.mdd.common.validator.annotation.IDMust;
import com.mdd.common.validator.annotation.IntegerContains;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import javax.validation.constraints.DecimalMax;
import javax.validation.constraints.DecimalMin;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Pattern;
import org.hibernate.validator.constraints.Length;

@ApiModel("系统部门更新参数")
public class SystemDeptUpdateValidate implements Serializable {
   private static final long serialVersionUID = 1L;
   @IDMust(
      message = "id参数必传且需大于0"
   )
   @ApiModelProperty(
      value = "id",
      required = true
   )
   private Integer id;
   @ApiModelProperty(
      value = "上级ID",
      required = true
   )
   private @NotNull(
   message = "pid参数缺失"
) @DecimalMin(
   value = "0",
   message = "上级值不能少于0"
) Integer pid;
   @ApiModelProperty("部门名称")
   private @NotNull(
   message = "name参数缺失"
) @Length(
   min = 1,
   max = 100,
   message = "部门名称必须在1~100个字符内"
) String name;
   private @Length(
   min = 1,
   max = 30,
   message = "负责人名称必须在1~30个字符内"
) String duty = "";
   @ApiModelProperty("手机号码")
   private @Length(
   min = 11,
   max = 11,
   message = "手机号只能为11位"
) @Pattern(
   regexp = "^[1][3,4,5,6,7,8,9][0-9]{9}$",
   message = "手机号格式有误"
) String mobile;
   @IntegerContains(
      values = {0, 1}
   )
   @ApiModelProperty("状态")
   private @NotNull(
   message = "请选择状态"
) Integer isStop;
   @ApiModelProperty("排序")
   private @DecimalMin(
   value = "0",
   message = "排序号值不能少于0"
) @DecimalMax(
   value = "9999",
   message = "排序号值不能大于9999"
) Integer sort;

   public Integer getId() {
      return this.id;
   }

   public @NotNull(
   message = "pid参数缺失"
) Integer getPid() {
      return this.pid;
   }

   public @NotNull(
   message = "name参数缺失"
) String getName() {
      return this.name;
   }

   public String getDuty() {
      return this.duty;
   }

   public String getMobile() {
      return this.mobile;
   }

   public @NotNull(
   message = "请选择状态"
) Integer getIsStop() {
      return this.isStop;
   }

   public Integer getSort() {
      return this.sort;
   }

   public void setId(Integer id) {
      this.id = id;
   }

   public void setPid(@NotNull(
   message = "pid参数缺失"
) Integer pid) {
      this.pid = pid;
   }

   public void setName(@NotNull(
   message = "name参数缺失"
) String name) {
      this.name = name;
   }

   public void setDuty(String duty) {
      this.duty = duty;
   }

   public void setMobile(String mobile) {
      this.mobile = mobile;
   }

   public void setIsStop(@NotNull(
   message = "请选择状态"
) Integer isStop) {
      this.isStop = isStop;
   }

   public void setSort(Integer sort) {
      this.sort = sort;
   }

   public boolean equals(Object o) {
      if (o == this) {
         return true;
      } else if (!(o instanceof SystemDeptUpdateValidate)) {
         return false;
      } else {
         SystemDeptUpdateValidate other = (SystemDeptUpdateValidate)o;
         if (!other.canEqual(this)) {
            return false;
         } else {
            label95: {
               Object this$id = this.getId();
               Object other$id = other.getId();
               if (this$id == null) {
                  if (other$id == null) {
                     break label95;
                  }
               } else if (this$id.equals(other$id)) {
                  break label95;
               }

               return false;
            }

            Object this$pid = this.getPid();
            Object other$pid = other.getPid();
            if (this$pid == null) {
               if (other$pid != null) {
                  return false;
               }
            } else if (!this$pid.equals(other$pid)) {
               return false;
            }

            Object this$isStop = this.getIsStop();
            Object other$isStop = other.getIsStop();
            if (this$isStop == null) {
               if (other$isStop != null) {
                  return false;
               }
            } else if (!this$isStop.equals(other$isStop)) {
               return false;
            }

            label74: {
               Object this$sort = this.getSort();
               Object other$sort = other.getSort();
               if (this$sort == null) {
                  if (other$sort == null) {
                     break label74;
                  }
               } else if (this$sort.equals(other$sort)) {
                  break label74;
               }

               return false;
            }

            label67: {
               Object this$name = this.getName();
               Object other$name = other.getName();
               if (this$name == null) {
                  if (other$name == null) {
                     break label67;
                  }
               } else if (this$name.equals(other$name)) {
                  break label67;
               }

               return false;
            }

            Object this$duty = this.getDuty();
            Object other$duty = other.getDuty();
            if (this$duty == null) {
               if (other$duty != null) {
                  return false;
               }
            } else if (!this$duty.equals(other$duty)) {
               return false;
            }

            Object this$mobile = this.getMobile();
            Object other$mobile = other.getMobile();
            if (this$mobile == null) {
               if (other$mobile != null) {
                  return false;
               }
            } else if (!this$mobile.equals(other$mobile)) {
               return false;
            }

            return true;
         }
      }
   }

   protected boolean canEqual(Object other) {
      return other instanceof SystemDeptUpdateValidate;
   }

   public int hashCode() {
      int PRIME = true;
      int result = 1;
      Object $id = this.getId();
      result = result * 59 + ($id == null ? 43 : $id.hashCode());
      Object $pid = this.getPid();
      result = result * 59 + ($pid == null ? 43 : $pid.hashCode());
      Object $isStop = this.getIsStop();
      result = result * 59 + ($isStop == null ? 43 : $isStop.hashCode());
      Object $sort = this.getSort();
      result = result * 59 + ($sort == null ? 43 : $sort.hashCode());
      Object $name = this.getName();
      result = result * 59 + ($name == null ? 43 : $name.hashCode());
      Object $duty = this.getDuty();
      result = result * 59 + ($duty == null ? 43 : $duty.hashCode());
      Object $mobile = this.getMobile();
      result = result * 59 + ($mobile == null ? 43 : $mobile.hashCode());
      return result;
   }

   public String toString() {
      return "SystemDeptUpdateValidate(id=" + this.getId() + ", pid=" + this.getPid() + ", name=" + this.getName() + ", duty=" + this.getDuty() + ", mobile=" + this.getMobile() + ", isStop=" + this.getIsStop() + ", sort=" + this.getSort() + ")";
   }
}
